@@ -62,7 +62,6 @@ function ViewModel() {
     self.statusInfo.publicipv4 = ko.observable();
     self.statusInfo.ipv6 = ko.observable();
     self.statusInfo.dnslookup = ko.observable();
-    self.statusInfo.delayed_decoder = ko.observable();
     self.statusInfo.delayed_assembler = ko.observable();
     self.statusInfo.loadavg = ko.observable();
     self.statusInfo.pystone = ko.observable();
@@ -134,6 +133,100 @@ function ViewModel() {
         return parseInt(self.nrWarnings()) + self.allMessages().length;
     })
 
+    self.updateCheckAllButtonState = function(section) {
+        setCheckAllState(`#multiedit-checkall-${section}`, `.${section}-table input[name="multiedit"]`)
+    }
+
+    // Add queue or history item to multi-edit list
+    self.addMultiEdit = function(item, event) {
+        // The parent model is either the queue or history
+        const model = this.parent;
+        const section = model.queueItems ? 'queue' : 'history';
+
+        if(event.shiftKey) {
+            checkShiftRange(`.${section}-table input[name="multiedit"]`);
+        }
+
+        if(event.currentTarget.checked) {
+            model.multiEditItems.push(item);
+
+            // History is not editable
+            // Only the queue will fire the multi-edit update
+            model.doMultiEditUpdate?.();
+        } else {
+            model.multiEditItems.remove(function(inList) { return inList.id == item.id; })
+        }
+
+        self.updateCheckAllButtonState(section);
+        return true;
+    }
+    
+    // Check all queue or history items
+    self.checkAllJobs = function(item, event) {
+        const section = event.currentTarget.closest('.multioperations-selector').id === 'history-options' ? 'history' : 'queue';
+        const model = section === 'history' ? self.history : self.queue;
+
+        const allChecks = $(`.${section}-table input[name="multiedit"]`).filter(':not(:disabled):visible');
+
+        self.updateCheckAllButtonState(section);
+
+        if(event.target.indeterminate || (event.target.checked && !event.target.indeterminate)) {
+            const allActive = allChecks.filter(":checked")
+            if(allActive.length === model.multiEditItems().length) {
+                model.multiEditItems.removeAll();
+                allActive.prop('checked', false)
+            } else {
+                allActive.each(function() {
+                    var item = ko.dataFor(this)
+                    model.multiEditItems.remove(function(inList) { return inList.id === item.id; })
+                    this.checked = false;
+                })
+            }
+        } else {
+            allChecks.prop('checked', true)
+            allChecks.each(function() { model.multiEditItems.push(ko.dataFor(this)) })
+            event.target.checked = true
+
+            model.multiEditUpdate?.();
+        }
+
+        self.updateCheckAllButtonState(section);
+        return true;
+    }
+
+    // Delete all selected queue or history items
+    self.doMultiDelete = function(item, event) {
+        const section = event.currentTarget.closest('.multioperations-selector').id === 'history-options' ? 'history' : 'queue';
+        const model = section === 'history' ? self.history : self.queue;
+
+        // Anything selected?
+        if(model.multiEditItems().length < 1) return;
+
+        if(!self.confirmDeleteHistory() || confirm(glitterTranslate.removeDown)) {
+            let strIDs = '';
+            $.each(model.multiEditItems(), function() {
+                strIDs = strIDs + this.id + ',';
+            })
+
+            showNotification('.main-notification-box-removing-multiple', 0, model.multiEditItems().length)
+
+            callAPI({
+                mode: section,
+                name: 'delete',
+                del_files: 1,
+                value: strIDs
+            }).then(function(response) {
+                if(response.status) {
+                    // Make sure the history doesnt flicker and then fade-out
+                    model.isLoading(true)
+                    self.refresh()
+                    model.multiEditItems.removeAll();
+                    hideNotification()
+                }
+            })
+        }
+    }
+
     // Update main queue
     self.updateQueue = function(response) {
         // Block in case off dragging
@@ -671,6 +764,11 @@ function ViewModel() {
         }
     }
 
+    // default to url input when modal is shown
+    $('#modal-add-nzb').on('shown.bs.modal', function() {
+      $('input[name="nzbURL"]').focus();
+    })
+
     // From the upload or filedrop
     self.addNZBFromFile = function(files, fileindex) {
         // First file
@@ -754,7 +852,6 @@ function ViewModel() {
             // Update basic
             self.statusInfo.folders(data.status.folders)
             self.statusInfo.loadavg(data.status.loadavg)
-            self.statusInfo.delayed_decoder(data.status.delayed_decoder)
             self.statusInfo.delayed_assembler(data.status.delayed_assembler)
 
             // Update the full set if the data is available
@@ -1334,6 +1431,12 @@ function ViewModel() {
     // And refresh now!
     self.refresh()
 
-    // Activate tooltips
-    if (!isMobile) $('[data-tooltip="true"]').tooltip({ trigger: 'hover', container: 'body' })
+    // Special options for (non) mobile
+    if (isMobile) {
+        // Disable accept parameter on file inputs, as it doesn't work on mobile Safari
+        $("input[accept!=''][accept]").attr("accept","")
+    } else {
+        // Activate tooltips
+        $('[data-tooltip="true"]').tooltip({ trigger: 'hover', container: 'body' })
+    }
 }
