@@ -159,6 +159,8 @@ function QueueListModel(parent) {
                 value: newValue
             })
         }
+        // Update pagination and counters
+        self.parent.refresh(true)
     });
 
     // Do we show search box. So it doesn't dissapear when nothing is found
@@ -253,7 +255,7 @@ function QueueListModel(parent) {
         // Reset form and remove all checked ones
         $form[0].reset();
         self.multiEditItems.removeAll();
-        $('.delete input[name="multiedit"], #multiedit-checkall').prop({'checked': false, 'indeterminate': false})
+        $('.queue-table input[name="multiedit"], .queue #multiedit-checkall').prop({'checked': false, 'indeterminate': false})
 
         // Is the multi-edit in view?
         if(($form.offset().top + $form.outerHeight(true)) > ($(window).scrollTop()+$(window).height())) {
@@ -264,72 +266,6 @@ function QueueListModel(parent) {
         }
     }
 
-    // Add to the list
-    self.addMultiEdit = function(item, event) {
-        // Is it a shift-click?
-        if(event.shiftKey) {
-            checkShiftRange('.queue-table input[name="multiedit"]');
-        }
-
-        // Add or remove from the list?
-        if(event.currentTarget.checked) {
-            // Add item
-            self.multiEditItems.push(item);
-            // Update them all
-            self.doMultiEditUpdate();
-        } else {
-            // Go over them all to know which one to remove
-            self.multiEditItems.remove(function(inList) { return inList.id == item.id; })
-        }
-
-        // Update check-all buton state
-        setCheckAllState('#multiedit-checkall', '.queue-table input[name="multiedit"]')
-        return true;
-    }
-
-    // Check all
-    self.checkAllJobs = function(item, event) {
-        // Get which ones we care about
-        var allChecks = $('.queue-table input[name="multiedit"]').filter(':not(:disabled):visible');
-
-        // We need to re-evaltuate the state of this check-all
-        // Otherwise the 'inderterminate' will be overwritten by the click event!
-        setCheckAllState('#multiedit-checkall', '.queue-table input[name="multiedit"]')
-
-        // Now we can check what happend
-        // For when some are checked, or all are checked (but not partly)
-        if(event.target.indeterminate || (event.target.checked && !event.target.indeterminate)) {
-            var allActive = allChecks.filter(":checked")
-            // First remove the from the list
-            if(allActive.length == self.multiEditItems().length) {
-                // Just remove all
-                self.multiEditItems.removeAll();
-                // Remove the check
-                allActive.prop('checked', false)
-            } else {
-                // Remove them seperate
-                allActive.each(function() {
-                    // Go over them all to know which one to remove
-                    var item = ko.dataFor(this)
-                    self.multiEditItems.remove(function(inList) { return inList.id == item.id; })
-                    // Remove the check of this one
-                    this.checked = false;
-                })
-            }
-        } else {
-            // None are checked, so check and add them all
-            allChecks.prop('checked', true)
-            allChecks.each(function() { self.multiEditItems.push(ko.dataFor(this)) })
-            event.target.checked = true
-
-            // Now we fire the update
-            self.doMultiEditUpdate()
-        }
-        // Set state of all the check-all's
-        setCheckAllState('#multiedit-checkall', '.queue-table input[name="multiedit"]')
-        return true;
-    }
-
     // Do the actual multi-update immediatly
     self.doMultiEditUpdate = function() {
         // Anything selected?
@@ -343,90 +279,61 @@ function QueueListModel(parent) {
         var newStatus = $('.multioperations-selector input[name="multiedit-status"]:checked').val()
 
         // List all the ID's
-        var  strIDs = '';
+        var strIDs = '';
         $.each(self.multiEditItems(), function(index) {
             strIDs = strIDs + this.id + ',';
         })
 
+        // All non-category updates need to only happen after a category update
+        function nonCatUpdates() {
+            if(newScript != '') {
+                callAPI({
+                    mode: 'change_script',
+                    value: strIDs,
+                    value2: newScript
+                })
+            }
+            if(newPrior != '') {
+                callAPI({
+                    mode: 'queue',
+                    name: 'priority',
+                    value: strIDs,
+                    value2: newPrior
+                })
+            }
+            if(newProc != '') {
+                callAPI({
+                    mode: 'change_opts',
+                    value: strIDs,
+                    value2: newProc
+                })
+            }
+            if(newStatus) {
+                callAPI({
+                    mode: 'queue',
+                    name: newStatus,
+                    value: strIDs
+                })
+            }
+
+            // Wat a little and do the refresh
+            // Only if anything changed!
+            if(newStatus || newProc != '' || newPrior != '' || newScript != '' || newCat != '') {
+                setTimeout(parent.refresh, 100)
+            }
+        }
+
         // What is changed?
         if(newCat != '') {
             callAPI({
                 mode: 'change_cat',
                 value: strIDs,
                 value2: newCat
-            })
-        }
-        if(newScript != '') {
-            callAPI({
-                mode: 'change_script',
-                value: strIDs,
-                value2: newScript
-            })
-        }
-        if(newPrior != '') {
-            callAPI({
-                mode: 'queue',
-                name: 'priority',
-                value: strIDs,
-                value2: newPrior
-            })
-        }
-        if(newProc != '') {
-            callAPI({
-                mode: 'change_opts',
-                value: strIDs,
-                value2: newProc
-            })
-        }
-        if(newStatus) {
-            callAPI({
-                mode: 'queue',
-                name: newStatus,
-                value: strIDs
-            })
+            }).then(nonCatUpdates)
+        } else {
+            nonCatUpdates()
         }
 
-        // Wat a little and do the refresh
-        // Only if anything changed!
-        if(newStatus || newProc != '' || newPrior != '' || newScript != '' || newCat != '') {
-            setTimeout(parent.refresh, 100)
-        }
-    }
-
-    // Selete all selected
-    self.doMultiDelete = function() {
-        // Anything selected?
-        if(self.multiEditItems().length < 1) return;
-
-        // Need confirm
-        if(!self.parent.confirmDeleteQueue() || confirm(glitterTranslate.removeDown)) {
-            // List all the ID's
-            var strIDs = '';
-            $.each(self.multiEditItems(), function(index) {
-                strIDs = strIDs + this.id + ',';
-            })
-
-            // Show notification
-            showNotification('.main-notification-box-removing-multiple', 0, self.multiEditItems().length)
-
-            // Remove
-            callAPI({
-                mode: 'queue',
-                name: 'delete',
-                del_files: 1,
-                value: strIDs
-            }).then(function(response) {
-                if(response.status) {
-                    // Make sure the queue doesnt flicker and then fade-out
-                    self.isLoading(true)
-                    self.parent.refresh()
-                    // Empty it
-                    self.multiEditItems.removeAll();
-                    // Hide notification
-                    hideNotification()
-                }
-            })
-        }
     }
 
     // On change of page we need to check all those that were in the list!
@@ -438,7 +345,7 @@ function QueueListModel(parent) {
             })
 
             // Update check-all buton state
-            setCheckAllState('#multiedit-checkall', '.queue-table input[name="multiedit"]')
+            setCheckAllState('.queue #multiedit-checkall', '.queue-table input[name="multiedit"]')
         }, 100)
     }, null, "arrayChange")
 }
