@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -108,7 +108,6 @@ class BPSMeter:
         "timeline_total",
         "article_stats_tried",
         "article_stats_failed",
-        "delayed_decoder",
         "delayed_assembler",
         "day_label",
         "end_of_day",
@@ -147,7 +146,6 @@ class BPSMeter:
         self.article_stats_tried: Dict[str, Dict[str, int]] = {}
         self.article_stats_failed: Dict[str, Dict[str, int]] = {}
 
-        self.delayed_decoder: int = 0
         self.delayed_assembler: int = 0
 
         self.day_label: str = time.strftime("%Y-%m-%d")
@@ -288,7 +286,6 @@ class BPSMeter:
             self.day_total = {}
 
             # Reset delayed counters so they don't go too high
-            self.delayed_decoder = 0
             self.delayed_assembler = 0
 
             # Check end of week and end of month
@@ -434,40 +431,6 @@ class BPSMeter:
         # We record every second, but display at the user's refresh-rate
         return self.bps_list[::refresh_rate]
 
-    def get_stable_speed(self, timespan: int = 10) -> Optional[int]:
-        """See if there is a stable speed the last <timespan> seconds
-        None: indicates it can't determine yet
-        0: the speed was not stable during <timespan>
-        Positive float: the speed was stable
-        """
-        if len(self.bps_list) < timespan:
-            return None
-
-        # Check if speed fell by more than 15%
-        try:
-            if self.bps_list[-1] / self.bps_list[-timespan] < 0.85:
-                return 0
-        except:
-            pass
-
-        # Calculate the variance in the speed
-        avg = sum(self.bps_list[-timespan:]) / timespan
-        vari = 0
-        for bps in self.bps_list[-timespan:]:
-            vari += abs(bps - avg)
-        vari = vari / timespan
-
-        try:
-            # See if the variance is less than 5%
-            if (vari / (self.bps / KIBI)) < 0.05:
-                return avg
-            else:
-                return 0
-        except:
-            # Probably one of the values was 0
-            pass
-        return None
-
     def reset_quota(self, force: bool = False):
         """Check if it's time to reset the quota, optionally resuming
         Return True, when still paused or should be paused
@@ -553,11 +516,9 @@ class BPSMeter:
             # Pattern = <day#> <hh:mm>
             # The <day> and <hh:mm> part can both be optional
             txt = cfg.quota_day().lower()
-            m = RE_DAY.search(txt)
-            if m:
+            if m := RE_DAY.search(txt):
                 self.q_day = int(m.group(1))
-            m = RE_HHMM.search(txt)
-            if m:
+            if m := RE_HHMM.search(txt):
                 self.q_hour = int(m.group(1))
                 self.q_minute = int(m.group(2))
             if self.q_period == "w":
