@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -474,8 +474,8 @@ def build_history_info(nzo, workdir_complete="", postproc_time=0, script_output=
 
     # Analyze series info only when job is finished
     series = ""
-    if series_info:
-        seriesname, season, episode = sabnzbd.newsunpack.analyse_show(nzo.final_name)[:3]
+    if series_info and (show_analysis := sabnzbd.newsunpack.analyse_show(nzo.final_name))["job_type"] == "tv":
+        seriesname, season, episode = (show_analysis[key] for key in ("title", "season", "episode"))
         if seriesname and season and episode:
             series = "%s/%s/%s" % (seriesname.lower(), season, episode)
 
@@ -554,7 +554,7 @@ def unpack_history_info(item: Union[Dict, sqlite3.Row]):
     return item
 
 
-def midnight_history_purge():
+def scheduled_history_purge():
     logging.info("Scheduled history purge")
     with HistoryDB() as history_db:
         history_db.auto_history_purge()
