@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -251,11 +251,19 @@ class DirectUnpacker(threading.Thread):
                     extracted = []
 
                     # Are there more files left?
-                    while self.nzo.files and not self.next_sets:
+                    while not self.nzo.removed_from_queue and not self.next_sets:
+                        logging.debug("Direct Unpack for %s waiting for more sets", self.nzo.final_name)
                         with self.next_file_lock:
                             self.next_file_lock.wait()
 
                     # Is there another set to do?
+                    logging.debug(
+                        "Direct Unpack for %s continuing: killed=%s, cur_setname=%s, next_sets=%s",
+                        self.nzo.final_name,
+                        self.killed,
+                        self.cur_setname,
+                        self.next_sets,
+                    )
                     if self.next_sets:
                         # Start new instance
                         nzf = self.next_sets.pop(0)
@@ -274,15 +282,13 @@ class DirectUnpacker(threading.Thread):
                     filename = re.search(RAR_EXTRACTFROM_RE, linebuf_encoded).group(1)
                     if filename not in rarfiles:
                         rarfiles.append(filename)
-                else:
+                elif m := re.search(RAR_EXTRACTED_RE, linebuf_encoded):
                     # List files we extracted
-                    m = re.search(RAR_EXTRACTED_RE, linebuf_encoded)
-                    if m:
-                        # In case of flat-unpack, UnRar still prints the whole path (?!)
-                        unpacked_file = m.group(2)
-                        if cfg.flat_unpack():
-                            unpacked_file = os.path.basename(unpacked_file)
-                        extracted.append(real_path(self.unpack_dir_info[0], unpacked_file))
+                    # In case of flat-unpack, UnRar still prints the whole path (?!)
+                    unpacked_file = m.group(2)
+                    if cfg.flat_unpack():
+                        unpacked_file = os.path.basename(unpacked_file)
+                    extracted.append(real_path(self.unpack_dir_info[0], unpacked_file))
 
             if linebuf.endswith(b"[C]ontinue, [Q]uit "):
                 # Stop timer
@@ -337,6 +343,7 @@ class DirectUnpacker(threading.Thread):
         self.reset_active()
         if self in ACTIVE_UNPACKERS:
             ACTIVE_UNPACKERS.remove(self)
+        logging.debug("Closing DirectUnpack for %s", self.nzo.final_name)
 
         # Set the thread to killed so it never gets restarted by accident
         self.killed = True
@@ -530,8 +537,7 @@ def analyze_rar_filename(filename):
     """Extract volume number and setname from rar-filenames
     Both ".part01.rar" and ".r01"
     """
-    m = RAR_NR.search(filename)
-    if m:
+    if m := RAR_NR.search(filename):
         if m.group(4):
             # Special since starts with ".rar", ".r00"
             return m.group(1), int_conv(m.group(4)) + 2
