@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2008-2017 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2017 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@ import os
 import pickle
 import sys
 import logging
+import logging.handlers
 import re
 import shutil
 import tempfile
@@ -31,6 +32,7 @@ import time
 import fnmatch
 import stat
 import ctypes
+import random
 from typing import Union, List, Tuple, Any, Dict, Optional, BinaryIO
 
 try:
@@ -41,10 +43,11 @@ except ImportError:
 
 import sabnzbd
 from sabnzbd.decorators import synchronized
-from sabnzbd.constants import FUTURE_Q_FOLDER, JOB_ADMIN, GIGI, DEF_FILE_MAX, IGNORED_FILES_AND_FOLDERS
+from sabnzbd.constants import FUTURE_Q_FOLDER, JOB_ADMIN, GIGI, DEF_FILE_MAX, IGNORED_FILES_AND_FOLDERS, DEF_LOG_FILE
 from sabnzbd.encoding import correct_unknown_encoding, utob, ubtou
 from sabnzbd.utils import rarfile
 
+
 # For Windows: determine executable extensions
 if os.name == "nt":
     PATHEXT = os.environ.get("PATHEXT", "").lower().split(";")
@@ -63,11 +66,10 @@ def get_ext(filename: str) -> str:
 def is_listed_ext(ext: str, ext_list: list) -> bool:
     """Check if the extension is listed. In case of a regexp the entire extension must be matched;
     partial matches aren't accepted (e.g. 'r[0-9]{2}' will be treated the same as '^r[0-9]{2}$' and
-    thus return false for extentions such as 'r007' despite the substring match on 'r00').
+    thus return false for extensions such as 'r007' despite the substring match on 'r00').
     """
     for item in ext_list:
-        RE_EXT = sabnzbd.misc.convert_filter(item)
-        if RE_EXT:
+        if RE_EXT := sabnzbd.misc.convert_filter(item):
             try:
                 if len(RE_EXT.match(ext).group()) == len(ext):
                     return True
@@ -120,6 +122,14 @@ def is_writable(path: str) -> bool:
         return True
 
 
+def is_size(filepath: str, size: int) -> bool:
+    """Return True if filepath exists and is specified size"""
+    try:
+        return os.path.getsize(filepath) == size
+    except:
+        return False
+
+
 _DEVICES = (
     "con",
     "prn",
@@ -176,10 +186,13 @@ def has_win_device(filename: str) -> bool:
     return False
 
 
-CH_ILLEGAL = "/"
-CH_LEGAL = "+"
-CH_ILLEGAL_WIN = '\\/<>?*|"\t:'
-CH_LEGAL_WIN = "++{}!@#'+-"
+CH_ILLEGAL = "\0/"
+CH_LEGAL = "_+"
+CH_ILLEGAL_WIN = '\\/<>?*|":'
+CH_LEGAL_WIN = "++{}!@#'-"
+for i in range(1, 32):
+    CH_ILLEGAL_WIN += chr(i)
+    CH_LEGAL_WIN += "_"
 
 
 def sanitize_filename(name: str) -> str:
@@ -197,7 +210,7 @@ def sanitize_filename(name: str) -> str:
         illegal += CH_ILLEGAL_WIN
         legal += CH_LEGAL_WIN
 
-    if ":" in name and sabnzbd.DARWIN:
+    if ":" in name and sabnzbd.MACOS:
         # Compensate for the foolish way par2 on macOS handles a colon character
         name = name[name.rfind(":") + 1 :]
 
@@ -258,13 +271,11 @@ def sanitize_foldername(name: str) -> str:
         illegal += CH_ILLEGAL_WIN
         legal += CH_LEGAL_WIN
 
-    repl = sabnzbd.cfg.replace_illegal()
     lst = []
     for ch in name.strip():
         if ch in illegal:
-            if repl:
-                ch = legal[illegal.find(ch)]
-                lst.append(ch)
+            ch = legal[illegal.find(ch)]
+            lst.append(ch)
         else:
             lst.append(ch)
     name = "".join(lst)
@@ -278,9 +289,8 @@ def sanitize_foldername(name: str) -> str:
     # And finally, make sure it doesn't end in a dot or a space
     # This is invalid on Windows and can cause trouble for some other tools
     if name != "." and name != "..":
-        # This would be perfect for := operator in Python 3.8+
-        while len(name.strip().rstrip(".")) < len(name):
-            name = name.strip().rstrip(".")
+        while len(name) > len(name := name.strip().rstrip(".")):
+            continue
 
     # Just to be sure we don't return nothing
     if not name:
@@ -381,7 +391,6 @@ def create_real_path(
     if path:
         my_dir = real_path(loc, path)
         if not os.path.exists(my_dir):
-            logging.info("%s directory: %s does not exist, try to create it", name, my_dir)
             if not create_all_dirs(my_dir, apply_permissions):
                 msg = T("Cannot create directory %s") % clip_path(my_dir)
                 logging.error(msg)
@@ -403,7 +412,7 @@ def same_file(a: str, b: str) -> int:
     return 1 if A and B are actually the same path
     return 2 if B is a subfolder of A
     """
-    if sabnzbd.WIN32 or sabnzbd.DARWIN:
+    if sabnzbd.WIN32 or sabnzbd.MACOS:
         a = clip_path(a.lower())
         b = clip_path(b.lower())
 
@@ -431,7 +440,7 @@ def check_mount(path: str) -> bool:
     """Return False if volume isn't mounted on Linux or macOS
     Retry 6 times with an interval of 1 sec.
     """
-    if sabnzbd.DARWIN:
+    if sabnzbd.MACOS:
         m = re.search(r"^(/Volumes/[^/]+)", path, re.I)
     elif sabnzbd.WIN32:
         m = re.search(r"^([a-z]:\\)", path, re.I)
@@ -447,22 +456,21 @@ def check_mount(path: str) -> bool:
     return not m
 
 
-RAR_RE = re.compile(r"\.(?P<ext>part\d*\.rar|rar|r\d\d|s\d\d|t\d\d|u\d\d|v\d\d|\d\d\d?\d)$", re.I)
+RAR_RE = re.compile(r"\.(part\d*\.rar|rar|r\d\d|s\d\d|t\d\d|u\d\d|v\d\d|\d\d\d?\d)$", re.I)
 SPLITFILE_RE = re.compile(r"\.(\d\d\d?\d$)", re.I)
-ZIP_RE = re.compile(r"\.(zip$)", re.I)
-SEVENZIP_RE = re.compile(r"\.7z$", re.I)
+SEVENZIP_RE = re.compile(r"\.(zip|7z)$", re.I)
 SEVENMULTI_RE = re.compile(r"\.7z\.\d+$", re.I)
 TS_RE = re.compile(r"\.(\d+)\.(ts$)", re.I)
 
 
 def build_filelists(
     workdir: Optional[str], workdir_complete: Optional[str] = None, check_both: bool = False, check_rar: bool = True
-) -> Tuple[List[str], List[str], List[str], List[str], List[str]]:
+) -> Tuple[List[str], List[str], List[str], List[str]]:
     """Build filelists, if workdir_complete has files, ignore workdir.
     Optionally scan both directories.
     Optionally test content to establish RAR-ness
     """
-    sevens, joinables, zips, rars, ts, filelist = ([], [], [], [], [], [])
+    sevens, joinables, rars, ts, filelist = ([], [], [], [], [])
 
     if workdir_complete:
         filelist.extend(listdir_full(workdir_complete))
@@ -478,14 +486,11 @@ def build_filelists(
 
         # Run through all the checks
         if SEVENZIP_RE.search(file) or SEVENMULTI_RE.search(file):
-            # 7zip
+            # 7zip or zip files
             sevens.append(file)
         elif SPLITFILE_RE.search(file) and not file_is_rar:
             # Joinables, optional with RAR check
             joinables.append(file)
-        elif ZIP_RE.search(file):
-            # ZIP files
-            zips.append(file)
         elif RAR_RE.search(file):
             # RAR files
             rars.append(file)
@@ -494,12 +499,11 @@ def build_filelists(
             ts.append(file)
 
     logging.debug("build_filelists(): joinables: %s", joinables)
-    logging.debug("build_filelists(): zips: %s", zips)
     logging.debug("build_filelists(): rars: %s", rars)
     logging.debug("build_filelists(): 7zips: %s", sevens)
     logging.debug("build_filelists(): ts: %s", ts)
 
-    return joinables, zips, rars, sevens, ts
+    return joinables, rars, sevens, ts
 
 
 def safe_fnmatch(f: str, pattern: str) -> bool:
@@ -533,7 +537,7 @@ def fix_unix_encoding(folder: str):
     This happens for example when files are created
     on Windows but unpacked/repaired on linux
     """
-    if not sabnzbd.WIN32 and not sabnzbd.DARWIN:
+    if not sabnzbd.WIN32 and not sabnzbd.MACOS:
         for root, dirs, files in os.walk(folder):
             for name in files:
                 new_name = correct_unknown_encoding(name)
@@ -616,8 +620,7 @@ def set_chmod(path: str, permissions: int, allow_failures: bool = False):
 def set_permissions(path: str, recursive: bool = True):
     """Give folder tree and its files their proper permissions"""
     if not sabnzbd.WIN32:
-        custom_permissions = sabnzbd.cfg.permissions()
-        if custom_permissions:
+        if custom_permissions := sabnzbd.cfg.permissions():
             # If user set permissions, parse them
             custom_permissions = int(custom_permissions, 8)
 
@@ -727,7 +730,7 @@ def create_all_dirs(path: str, apply_permissions: bool = False) -> Union[str, bo
 
 
 @synchronized(DIR_LOCK)
-def get_unique_dir(path: str, n: int = 0, create_dir: bool = True) -> str:
+def get_unique_dir(path: str, n: int = 0, create_dir: bool = True) -> Union[str, bool]:
     """Determine a unique folder or filename"""
     if not check_mount(path):
         return path
@@ -766,7 +769,8 @@ def listdir_full(input_dir: str, recursive: bool = True) -> List[str]:
     filelist = []
     for root, dirs, files in os.walk(input_dir):
         for file in files:
-            if not sabnzbd.misc.match_str(root, IGNORED_FILES_AND_FOLDERS):
+            # Ignore special folders and resources files created by macOS
+            if not sabnzbd.misc.match_str(root, IGNORED_FILES_AND_FOLDERS) and not file.startswith("._"):
                 filelist.append(os.path.join(root, file))
         if not recursive:
             break
@@ -842,11 +846,15 @@ def cleanup_empty_directories(path: str):
 @synchronized(DIR_LOCK)
 def renamer(old: str, new: str, create_local_directories: bool = False) -> str:
     """Rename file/folder with retries for Win32
-    Optionally alows the creation of local directories if they don't exist yet
+    Optionally allows the creation of local directories if they don't exist yet
     Returns new filename (which could be changed due to sanitize_filename) on success"""
-    # Sanitize last part of new name
+    # Sanitize last part of new name, just to be sure
     path, name = os.path.split(new)
-    new = os.path.join(path, sanitize_filename(name))
+    if os.path.isdir(old):
+        name = sanitize_foldername(name)
+    else:
+        name = sanitize_filename(name)
+    new = os.path.join(path, name)
 
     # Skip if nothing changes
     if old == new:
@@ -1021,7 +1029,7 @@ def diskspace_base(dir_to_check: str) -> Tuple[float, float]:
             return disk_size / GIGI, available / GIGI
         except:
             return 0.0, 0.0
-    elif sabnzbd.DARWIN:
+    elif sabnzbd.MACOS:
         # MacOS diskfree ... via c-lib call statfs()
         disk_size, available = disk_free_macos_clib_statfs64(dir_to_check)
         return disk_size / GIGI, available / GIGI
@@ -1202,7 +1210,7 @@ def check_incomplete_vs_complete():
 def wait_for_download_folder():
     """Wait for download folder to become available"""
     while not sabnzbd.cfg.download_dir.test_path():
-        logging.debug('Waiting for "incomplete" folder')
+        logging.debug("Waiting for incomplete folder")
         time.sleep(2.0)
 
 
@@ -1214,14 +1222,15 @@ def backup_exists(filename: str) -> bool:
 
 def backup_nzb(nzb_path: str):
     """Backup NZB file, return path to nzb if it was saved"""
-    nzb_backup_dir = sabnzbd.cfg.nzb_backup_dir.get_path()
-    if nzb_backup_dir:
+    if nzb_backup_dir := sabnzbd.cfg.nzb_backup_dir.get_path():
         logging.debug("Saving copy of %s in %s", get_filename(nzb_path), nzb_backup_dir)
         shutil.copy(nzb_path, nzb_backup_dir)
 
 
 def save_compressed(folder: str, filename: str, data_fp: BinaryIO) -> str:
     """Save compressed NZB file in folder, return path to saved nzb file"""
+    # Make sure it's a clean filename
+    filename = sanitize_filename(filename)
     if filename.endswith(".nzb"):
         filename += ".gz"
     else:
@@ -1244,3 +1253,70 @@ def save_compressed(folder: str, filename: str, data_fp: BinaryIO) -> str:
         logging.info("Skipping existing file %s", full_nzb_path)
 
     return full_nzb_path
+
+
+def purge_log_files():
+    """Purge all existing log files"""
+    # First we need to do a rollover
+    for handler in logging.root.manager.root.handlers:
+        if isinstance(handler, logging.handlers.RotatingFileHandler):
+            # Only if we have a FilderHandler we can rollover and delete older ones
+            logging.debug("Purging log files")
+            handler.doRollover()
+
+            # Keep sabnzbd.log but remove all older ones
+            remove_all(sabnzbd.cfg.log_dir.get_path(), pattern=DEF_LOG_FILE + ".*", keep_folder=True)
+            logging.debug("Finished puring log files")
+
+
+def directory_is_writable_with_file(mydir, myfilename):
+    filename = os.path.join(mydir, myfilename)
+    if os.path.exists(filename):
+        try:
+            os.remove(filename)
+        except:
+            return False
+    try:
+        with open(filename, "w") as f:
+            f.write("Some random content")
+        os.remove(filename)
+        return True
+    except:
+        return False
+
+
+def directory_is_writable(test_dir: str) -> bool:
+    """Checks if dir is writable at all, with long filenames, with unicode,
+    and (on non-Windows), writable with special chars.
+    Returns True if all OK, otherwise False"""
+    if not directory_is_writable_with_file(test_dir, "sab_test.txt"):
+        sabnzbd.misc.helpful_warning(T("%s is not writable at all. This blocks downloads."), test_dir)
+        return False
+    return True
+
+
+def check_filesystem_capabilities(test_dir: str) -> bool:
+    """Checks if we can write long and unicode filenames to the given directory.
+    If not on Windows, also check for special chars like slashes and :
+    Returns True if all OK, otherwise False"""
+
+    allgood = True  # default return value: all OK
+
+    # long filename; normal filesystems accept 255 byte filenames
+    if not directory_is_writable_with_file(test_dir, "A" * 245 + str(random.randrange(10000, 99999))):
+        sabnzbd.misc.helpful_warning(T("Cannot write a long filename to %s. This can cause problems."), test_dir)
+        allgood = False
+
+    # unicode in filename
+    if not directory_is_writable_with_file(test_dir, "🚀" * 20):
+        sabnzbd.misc.helpful_warning(T("Cannot write a unicode filename to %s. This can cause problems."), test_dir)
+        allgood = False
+
+    # if not on Windows, check special chars like \ and :
+    if not sabnzbd.WIN32 and not directory_is_writable_with_file(test_dir, "sab_test \\ bla :: , bla.txt"):
+        sabnzbd.misc.helpful_warning(
+            T("%s is not writable with special character filenames. This can cause problems."), test_dir
+        )
+        allgood = False
+
+    return allgood
