@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -49,6 +49,7 @@ from sabnzbd.misc import (
     is_ipv6_addr,
     get_server_addrinfo,
     is_lan_addr,
+    is_local_addr,
     is_loopback_addr,
     ip_in_subnet,
     helpful_warning,
@@ -70,7 +71,17 @@ import sabnzbd.newsunpack
 from sabnzbd.utils.servertests import test_nntp_server_dict
 from sabnzbd.utils.getperformance import getcpu
 import sabnzbd.utils.ssdp
-from sabnzbd.constants import DEF_STD_CONFIG, DEFAULT_PRIORITY, CHEETAH_DIRECTIVES, EXCLUDED_GUESSIT_PROPERTIES
+from sabnzbd.constants import (
+    DEF_STD_CONFIG,
+    DEFAULT_PRIORITY,
+    CHEETAH_DIRECTIVES,
+    EXCLUDED_GUESSIT_PROPERTIES,
+    DEF_HTTPS_CERT_FILE,
+    DEF_SORTER_RENAME_SIZE,
+    GUESSIT_SORT_TYPES,
+    VALID_NZB_FILES,
+    VALID_ARCHIVES,
+)
 from sabnzbd.lang import list_languages
 from sabnzbd.api import (
     list_scripts,
@@ -196,15 +207,15 @@ def check_access(access_type: int = 4, warn_user: bool = False) -> bool:
 
     remote_ip = cherrypy.request.remote.ip
 
-    # Check for localhost
-    if is_loopback_addr(remote_ip):
-        return True
+    # Check if the client IP is a loopback address or considered local
+    is_allowed = is_loopback_addr(remote_ip) or is_local_addr(remote_ip)
 
-    if not cfg.local_ranges():
-        # No local ranges defined, allow all private addresses by default
-        is_allowed = is_lan_addr(remote_ip)
-    else:
-        is_allowed = any(ip_in_subnet(remote_ip, r) for r in cfg.local_ranges())
+    # Never check the XFF header unless access would have been granted based on the remote IP alone!
+    if is_allowed and cfg.verify_xff_header() and (xff_header := cherrypy.request.headers.get("X-Forwarded-For")):
+        xff_ips = [ip.strip() for ip in xff_header.split(",")]
+        is_allowed = all(is_local_addr(ip) or is_loopback_addr(ip) for ip in xff_ips)
+        if not is_allowed:
+            logging.debug("Denying access based on X-Forwarded-For header '%s'", xff_header)
 
     if not is_allowed and warn_user:
         log_warning_and_ip(T("Refused connection from:"))
@@ -420,7 +431,7 @@ class MainPage:
             info["have_watched_dir"] = bool(cfg.dirscan_dir())
 
             info["cpumodel"] = getcpu()
-            info["cpusimd"] = sabnzbd.decoder.SABYENC_SIMD
+            info["cpusimd"] = sabnzbd.decoder.SABCTOOLS_SIMD
 
             # Have logout only with HTML and if inet=5, only when we are external
             info["have_logout"] = (
@@ -519,7 +530,7 @@ class Wizard:
             info["username"] = ""
             info["password"] = ""
             info["connections"] = ""
-            info["ssl"] = 0
+            info["ssl"] = 1
             info["ssl_verify"] = 2
         else:
             # Sort servers to get the first enabled one
@@ -674,10 +685,8 @@ class ConfigPage:
         conf["cmdline"] = sabnzbd.CMDLINE
         conf["build"] = sabnzbd.__baseline__[:7]
 
-        conf["have_unzip"] = bool(sabnzbd.newsunpack.ZIP_COMMAND)
         conf["have_7zip"] = bool(sabnzbd.newsunpack.SEVENZIP_COMMAND)
-        conf["have_sabyenc"] = sabnzbd.decoder.SABYENC_ENABLED
-        conf["have_mt_par2"] = sabnzbd.newsunpack.PAR2_MT
+        conf["have_par2_turbo"] = sabnzbd.newsunpack.PAR2_TURBO
 
         conf["certificate_validation"] = sabnzbd.CERTIFICATE_VALIDATION
         conf["ssl_version"] = ssl.OPENSSL_VERSION
@@ -717,6 +726,8 @@ class ConfigFolders:
     def index(self, **kwargs):
         conf = build_header(sabnzbd.WEB_DIR_CONFIG)
 
+        conf["file_exts"] = ", ".join(VALID_NZB_FILES + VALID_ARCHIVES)
+
         for kw in LIST_DIRPAGE + LIST_BOOL_DIRPAGE:
             conf[kw] = config.get_config("misc", kw)()
 
@@ -774,7 +785,6 @@ SWITCH_LIST = (
     "sfv_check",
     "deobfuscate_final_filenames",
     "folder_rename",
-    "load_balancing",
     "quota_size",
     "quota_day",
     "quota_resume",
@@ -788,7 +798,6 @@ SWITCH_LIST = (
     "no_series_dupes",
     "series_propercheck",
     "script_can_fail",
-    "new_nzb_on_failure",
     "unwanted_extensions",
     "action_on_unwanted_extensions",
     "unwanted_extensions_mode",
@@ -840,6 +849,7 @@ SPECIAL_BOOL_LIST = (
     "start_paused",
     "preserve_paused_state",
     "no_penalties",
+    "ipv6_servers",
     "fast_fail",
     "overwrite_files",
     "enable_par_cleanup",
@@ -848,8 +858,8 @@ SPECIAL_BOOL_LIST = (
     "api_warnings",
     "helpful_warnings",
     "ampm",
+    "enable_multipar",
     "enable_unrar",
-    "enable_unzip",
     "enable_7zip",
     "enable_filejoin",
     "enable_tsjoin",
@@ -860,6 +870,7 @@ SPECIAL_BOOL_LIST = (
     "ipv6_hosting",
     "keep_awake",
     "empty_postproc",
+    "new_nzb_on_failure",
     "html_login",
     "wait_for_dfolder",
     "enable_broadcast",
@@ -868,21 +879,21 @@ SPECIAL_BOOL_LIST = (
     "api_logging",
     "x_frame_options",
     "allow_old_ssl_tls",
+    "enable_season_sorting",
+    "verify_xff_header",
 )
 SPECIAL_VALUE_LIST = (
     "downloader_sleep_time",
     "size_limit",
-    "movie_rename_limit",
-    "episode_rename_limit",
     "nomedia_marker",
     "max_url_retries",
     "req_completion_rate",
     "wait_ext_drive",
     "max_foldername_length",
     "url_base",
-    "num_simd_decoders",
+    "receive_threads",
+    "switchinterval",
     "direct_unpack_threads",
-    "ipv6_servers",
     "selftest_host",
     "ssdp_broadcast_interval",
 )
@@ -959,7 +970,6 @@ class ConfigGeneral:
 
     @secured_expose(check_configlock=True)
     def index(self, **kwargs):
-
         conf = build_header(sabnzbd.WEB_DIR_CONFIG)
 
         conf["certificate_validation"] = sabnzbd.CERTIFICATE_VALIDATION
@@ -980,6 +990,7 @@ class ConfigGeneral:
 
         conf["language"] = cfg.language()
         conf["lang_list"] = list_languages()
+        conf["def_https_cert_file"] = DEF_HTTPS_CERT_FILE
 
         for kw in GENERAL_LIST:
             conf[kw] = config.get_config("misc", kw)()
@@ -1073,7 +1084,7 @@ class ConfigServer:
             % (int(not servers[svr].enable()), servers[svr].priority(), servers[svr].displayname().lower()),
         )
         for svr in server_names:
-            new.append(servers[svr].get_dict(safe=True))
+            new.append(servers[svr].get_dict(for_public_api=True))
             t, m, w, d, daily, articles_tried, articles_success = sabnzbd.BPSMeter.amounts(svr)
             if t:
                 new[-1]["amounts"] = (
@@ -1152,17 +1163,6 @@ def unique_svr_name(server):
     return new_name
 
 
-def check_server(host, port, ajax):
-    """Check if server address resolves properly"""
-    if host.lower() == "localhost" and sabnzbd.AMBI_LOCALHOST:
-        return badParameterResponse(T("Warning: LOCALHOST is ambiguous, use numerical IP-address."), ajax)
-
-    if get_server_addrinfo(host, int_conv(port)):
-        return ""
-    else:
-        return badParameterResponse(T('Server address "%s:%s" is not valid.') % (host, port), ajax)
-
-
 def handle_server(kwargs, root=None, new_svr=False):
     """Internal server handler"""
     ajax = kwargs.get("ajax")
@@ -1182,9 +1182,8 @@ def handle_server(kwargs, root=None, new_svr=False):
         kwargs["connections"] = "1"
 
     if kwargs.get("enable") == "1":
-        msg = check_server(host, port, ajax)
-        if msg:
-            return msg
+        if not get_server_addrinfo(host, int_conv(port)):
+            return badParameterResponse(T('Server address "%s:%s" is not valid.') % (host, port), ajax)
 
     # Default server name is just the host name
     server = host
@@ -1817,20 +1816,6 @@ class ConfigCats:
 
 
 ##############################################################################
-SORT_LIST = (
-    "enable_tv_sorting",
-    "tv_sort_string",
-    "tv_categories",
-    "enable_movie_sorting",
-    "movie_sort_string",
-    "movie_sort_extra",
-    "enable_date_sorting",
-    "date_sort_string",
-    "movie_categories",
-    "date_categories",
-)
-
-
 class ConfigSorting:
     def __init__(self, root):
         self.__root = root
@@ -1838,14 +1823,26 @@ class ConfigSorting:
     @secured_expose(check_configlock=True)
     def index(self, **kwargs):
         conf = build_header(sabnzbd.WEB_DIR_CONFIG)
-        conf["complete_dir"] = cfg.complete_dir.get_clipped_path()
 
-        for kw in SORT_LIST:
-            conf[kw] = config.get_config("misc", kw)()
+        sorters = config.get_ordered_sorters()
+        # Add empty sorter entry, used as a template at the top of the page
+        empty = {
+            "is_active": "1",
+            "name": "",
+            "order": len(sorters),  # Last in line
+            "min_size": DEF_SORTER_RENAME_SIZE,
+            "sort_string": "",
+            "sort_cats": "",
+            "sort_type": "0,",
+            "multipart_label": "",
+        }
+        sorters.insert(0, empty)
+        conf["slotinfo"] = sorters
         conf["categories"] = list_cats(False)
         conf["guessit_properties"] = tuple(
             prop for prop in guessit_properties().keys() if prop not in EXCLUDED_GUESSIT_PROPERTIES
         )
+        conf["sort_types"] = GUESSIT_SORT_TYPES
 
         return template_filtered_response(
             file=os.path.join(sabnzbd.WEB_DIR_CONFIG, "config_sorting.tmpl"),
@@ -1853,17 +1850,41 @@ class ConfigSorting:
         )
 
     @secured_expose(check_api_key=True, check_configlock=True)
-    def saveSorting(self, **kwargs):
-        for kw in SORT_LIST:
-            item = config.get_config("misc", kw)
-            value = kwargs.get(kw)
-            msg = item.set(value)
-            if msg:
-                return badParameterResponse(msg)
+    def delete(self, **kwargs):
+        kwargs["section"] = "sorters"
+        kwargs["keyword"] = kwargs.get("name")
+        del_from_section(kwargs)
+        raise Raiser(self.__root)
+
+    @secured_expose(check_api_key=True, check_configlock=True)
+    def save_sorter(self, **kwargs):
+        name = kwargs.get("name", "*")
+        newname = kwargs.get("newname", "")
+        newname = config.clean_section_name(newname)
+
+        if name == "*":
+            newname = name
+        if newname:
+            # Delete current one and replace with new one
+            if name:
+                config.delete("sorters", name)
+            config.ConfigSorter(newname, kwargs)
 
         config.save_config()
         raise Raiser(self.__root)
 
+    @secured_expose(check_api_key=True, check_configlock=True)
+    def toggle_sorter(self, **kwargs):
+        """Toggle is_active flag of a sorter"""
+        try:
+            sorter = config.get_sorters()[kwargs.get("sorter")]
+            sorter.is_active.set(not sorter.is_active())
+            config.save_config()
+        except Exception:
+            pass
+
+        raise Raiser(self.__root)
+
 
 def badParameterResponse(msg, ajax=None):
     """Return a html page with error message and a 'back' button"""
