@@ -1,6 +1,6 @@
 #!/usr/bin/python3 -OO
 # -*- coding: utf-8 -*-
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -161,7 +161,7 @@ LanguageTable = {
     "om": ("Oromo", "Afaan Oromoo", 0, False),
     "pl": ("Polish", "Polski", 0, False),
     "pt": ("Portuguese", "Português", 0, False),
-    "pt_BR": ("Portuguese Brazillian", "Português Brasileiro", 0, False),
+    "pt_BR": ("Portuguese Brazilian", "Português Brasileiro", 0, False),
     "rm": ("Romansh", "Rumantsch grischun", 0, False),
     "rn": ("Kirundi", "kiRundi", 0, False),
     "ro": ("Romanian", "Româna", 1250, False),
