@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -40,10 +40,17 @@ from typing import Union, Tuple, Any, AnyStr, Optional, List, Dict
 
 import sabnzbd
 import sabnzbd.getipaddress
-from sabnzbd.constants import DEFAULT_PRIORITY, MEBI, DEF_ARTICLE_CACHE_DEFAULT, DEF_ARTICLE_CACHE_MAX, REPAIR_REQUEST
+from sabnzbd.constants import (
+    DEFAULT_PRIORITY,
+    MEBI,
+    DEF_ARTICLE_CACHE_DEFAULT,
+    DEF_ARTICLE_CACHE_MAX,
+    REPAIR_REQUEST,
+    GUESSIT_SORT_TYPES,
+)
 import sabnzbd.config as config
 import sabnzbd.cfg as cfg
-from sabnzbd.encoding import ubtou, platform_btou
+from sabnzbd.encoding import ubtou
 from sabnzbd.filesystem import userxbit, make_script_path, remove_file, is_valid_script
 
 if sabnzbd.WIN32:
@@ -130,25 +137,18 @@ def calc_age(date: datetime.datetime, trans: bool = False) -> str:
         d = "d"
         h = "h"
         m = "m"
+
     try:
-        now = datetime.datetime.now()
-        # age = str(now - date).split(".")[0] #old calc_age
-
-        # time difference
-        dage = now - date
-        seconds = dage.seconds
-        # only one value should be returned
-        # if it is less than 1 day then it returns in hours, unless it is less than one hour where it returns in minutes
-        if dage.days:
-            age = "%d%s" % (dage.days, d)
-        elif int(seconds / 3600):
-            age = "%d%s" % (seconds / 3600, h)
+        # Return time difference in human-readable format
+        date_diff = datetime.datetime.now() - date
+        if date_diff.days:
+            return "%d%s" % (date_diff.days, d)
+        elif int(date_diff.seconds / 3600):
+            return "%d%s" % (date_diff.seconds / 3600, h)
         else:
-            age = "%d%s" % (seconds / 60, m)
+            return "%d%s" % (date_diff.seconds / 60, m)
     except:
-        age = "-"
-
-    return age
+        return "-"
 
 
 def safe_lower(txt: Any) -> str:
@@ -240,6 +240,16 @@ def opts_to_pp(repair: bool, unpack: bool, delete: bool) -> int:
     return 0
 
 
+def sort_to_opts(sort_type: str) -> int:
+    """Convert a guessed sort_type to its integer equivalent"""
+    for k, v in GUESSIT_SORT_TYPES.items():
+        if v == sort_type:
+            return k
+    else:
+        logging.debug("Invalid sort_type %s, pretending a match to 0 ('all')", sort_type)
+        return 0
+
+
 _wildcard_to_regex = {
     "\\": r"\\",
     "^": r"\^",
@@ -379,8 +389,7 @@ def convert_version(text):
     """Convert version string to numerical value and a testversion indicator"""
     version = 0
     test = True
-    m = RE_VERSION.search(ubtou(text))
-    if m:
+    if m := RE_VERSION.search(ubtou(text)):
         version = int(m.group(1)) * 1000000 + int(m.group(2)) * 10000 + int(m.group(3)) * 100
         try:
             if m.group(4).lower() == "rc":
@@ -508,8 +517,8 @@ def from_units(val: str) -> float:
     val = str(val).strip().upper()
     if val == "-1":
         return float(val)
-    m = RE_UNITS.search(val)
-    if m:
+
+    if m := RE_UNITS.search(val):
         if m.group(2):
             val = float(m.group(1))
             unit = m.group(2)
@@ -773,10 +782,9 @@ def format_time_string(seconds: float) -> str:
 def int_conv(value: Any) -> int:
     """Safe conversion to int (can handle None)"""
     try:
-        value = int(value)
+        return int(value)
     except:
-        value = 0
-    return value
+        return 0
 
 
 def create_https_certificates(ssl_cert, ssl_key):
@@ -968,6 +976,15 @@ def is_lan_addr(ip: str) -> bool:
         return False
 
 
+def is_local_addr(ip: str) -> bool:
+    """Determine if an IP address is to be considered local, i.e. it's part of a subnet in
+    local_ranges, if defined, or in private address space reserved for local area networks."""
+    if local_ranges := cfg.local_ranges():
+        return any(ip_in_subnet(ip, local_range) for local_range in local_ranges)
+    else:
+        return is_lan_addr(ip)
+
+
 def ip_extract() -> List[str]:
     """Return list of IP addresses of this system"""
     ips = []
@@ -999,38 +1016,15 @@ def ip_extract() -> List[str]:
 
 
 def get_server_addrinfo(host: str, port: int) -> socket.getaddrinfo:
-    """Return processed getaddrinfo()"""
+    """Return getaddrinfo() based on user settings"""
     try:
-        int(port)
-    except:
-        port = 119
-    opt = sabnzbd.cfg.ipv6_servers()
-    """ ... with the following meaning for 'opt':
-    Control the use of IPv6 Usenet server addresses. Meaning:
-    0 = don't use
-    1 = use when available and reachable (DEFAULT)
-    2 = force usage (when SABnzbd's detection fails)
-    """
-    try:
-        # Standard IPV4 or IPV6
-        ips = socket.getaddrinfo(host, port, 0, socket.SOCK_STREAM)
-        if opt == 2 or (opt == 1 and sabnzbd.EXTERNAL_IPV6) or (opt == 1 and sabnzbd.cfg.load_balancing() == 2):
-            # IPv6 forced by user, or IPv6 allowed and reachable, or IPv6 allowed and loadbalancing-with-IPv6 activated
-            # So return all IP addresses, no matter IPv4 or IPv6:
-            return ips
+        if cfg.ipv6_servers():
+            # Standard IPV4 or IPV6
+            return socket.getaddrinfo(host, port, socket.AF_UNSPEC, socket.SOCK_STREAM)
         else:
-            # IPv6 unreachable or not allowed by user, so only return IPv4 address(es):
-            return [ip for ip in ips if ":" not in ip[4][0]]
+            # Only IPv4
+            return socket.getaddrinfo(host, port, socket.AF_INET, socket.SOCK_STREAM)
     except:
-        if opt == 2 or (opt == 1 and sabnzbd.EXTERNAL_IPV6) or (opt == 1 and sabnzbd.cfg.load_balancing() == 2):
-            try:
-                # Try IPV6 explicitly
-                return socket.getaddrinfo(
-                    host, port, socket.AF_INET6, socket.SOCK_STREAM, socket.IPPROTO_IP, socket.AI_CANONNAME
-                )
-            except:
-                # Nothing found!
-                pass
         return []
 
 
@@ -1058,20 +1052,6 @@ def match_str(text: AnyStr, matches: Tuple[AnyStr, ...]) -> Optional[AnyStr]:
     return None
 
 
-def nntp_to_msg(text: Union[List[AnyStr], str]) -> str:
-    """Format raw NNTP bytes data for display"""
-    if isinstance(text, list):
-        text = text[0]
-
-    # Only need to split if it was raw data
-    # Sometimes (failed login) we put our own texts
-    if not isinstance(text, bytes):
-        return text
-    else:
-        lines = text.split(b"\r\n")
-        return ubtou(lines[0])
-
-
 def recursive_html_escape(input_dict_or_list: Union[Dict[str, Any], List], exclude_items: Tuple[str, ...] = ()):
     """Recursively update the input_dict in-place with html-safe values"""
     if isinstance(input_dict_or_list, (dict, list)):
@@ -1107,7 +1087,7 @@ def list2cmdline_unrar(lst: List[str]) -> str:
     return " ".join(nlst)
 
 
-def build_and_run_command(command: List[str], windows_unrar_command: bool = False, **kwargs):
+def build_and_run_command(command: List[str], windows_unrar_command: bool = False, text_mode: bool = True, **kwargs):
     """Builds and then runs command with necessary flags and optional
     IONice and Nice commands. Optional Popen arguments can be supplied.
     On Windows we need to run our own list2cmdline for Unrar.
@@ -1153,12 +1133,18 @@ def build_and_run_command(command: List[str], windows_unrar_command: bool = Fals
 
     # Set the basic Popen arguments
     popen_kwargs = {
-        "stdin": subprocess.PIPE,
         "stdout": subprocess.PIPE,
         "stderr": subprocess.STDOUT,
+        "bufsize": 0,
         "startupinfo": startupinfo,
         "creationflags": creationflags,
     }
+
+    # In text mode we ignore errors
+    if text_mode:
+        # We default to utf8, and hope for the best
+        popen_kwargs.update({"text": True, "encoding": "utf8", "errors": "replace"})
+
     # Update with the supplied ones
     popen_kwargs.update(kwargs)
 
@@ -1171,7 +1157,7 @@ def build_and_run_command(command: List[str], windows_unrar_command: bool = Fals
 def run_command(cmd: List[str], **kwargs):
     """Run simple external command and return output as a string."""
     with build_and_run_command(cmd, **kwargs) as p:
-        txt = platform_btou(p.stdout.read())
+        txt = p.stdout.read()
         p.wait()
     return txt
 
@@ -1214,34 +1200,6 @@ def set_https_verification(value):
     return prev
 
 
-def test_ipv6():
-    """Check if external IPv6 addresses are reachable"""
-    if not cfg.selftest_host():
-        # User disabled the test, assume active IPv6
-        return True
-    try:
-        info = sabnzbd.getipaddress.addresslookup6(cfg.selftest_host())
-    except:
-        logging.debug(
-            "Test IPv6: Disabling IPv6, because it looks like it's not available. Reason: %s", sys.exc_info()[0]
-        )
-        return False
-
-    try:
-        af, socktype, proto, canonname, sa = info[0]
-        with socket.socket(af, socktype, proto) as sock:
-            sock.settimeout(2)  # 2 second timeout
-            sock.connect(sa[0:2])
-        logging.debug("Test IPv6: IPv6 test successful. Enabling IPv6")
-        return True
-    except socket.error:
-        logging.debug("Test IPv6: Cannot reach IPv6 test host. Disabling IPv6")
-        return False
-    except:
-        logging.debug("Test IPv6: Problem during IPv6 connect. Disabling IPv6. Reason: %s", sys.exc_info()[0])
-        return False
-
-
 def test_cert_checking():
     """Test quality of certificate validation"""
     # User disabled the test, assume proper SSL certificates
@@ -1391,3 +1349,88 @@ def history_updated():
     # Never go over the limit
     if sabnzbd.LAST_HISTORY_UPDATE + 1 >= sys.maxsize:
         sabnzbd.LAST_HISTORY_UPDATE = 1
+
+
+def convert_sorter_settings():
+    """Convert older tv/movie/date sorter settings to the new universal sorter
+
+    The old settings used:
+    -enable_tv_sorting = OptionBool("misc", "enable_tv_sorting", False)
+    -tv_sort_string = OptionStr("misc", "tv_sort_string")
+    -tv_categories = OptionList("misc", "tv_categories", ["tv"])
+
+    -enable_movie_sorting = OptionBool("misc", "enable_movie_sorting", False)
+    -movie_sort_string = OptionStr("misc", "movie_sort_string")
+    -movie_sort_extra = OptionStr("misc", "movie_sort_extra", "-cd%1", strip=False)
+    -movie_categories = OptionList("misc", "movie_categories", ["movies"])
+
+    -enable_date_sorting = OptionBool("misc", "enable_date_sorting", False)
+    -date_sort_string = OptionStr("misc", "date_sort_string")
+    -date_categories = OptionList("misc", "date_categories", ["tv"])
+
+    -movie_rename_limit = OptionStr("misc", "movie_rename_limit", "100M")
+    -episode_rename_limit = OptionStr("misc", "episode_rename_limit", "20M")
+
+    The new settings define a sorter as follows (cf. class config.ConfigSorter):
+    name: str {
+        name: str
+        order: int
+        min_size: Union[str|int] = "50M"
+        multipart_label: Optional[str] = ""
+        sort_string: str
+        sort_cats: List[str]
+        sort_type: List[int]
+        is_active: bool = 1
+    }
+
+    With the old settings, sorting was tried in a fixed order (series first, movies last);
+    that order is retained by the conversion code.
+    We only convert enabled sorters."""
+
+    # Keep track of order
+    order = 0
+
+    if cfg.enable_tv_sorting() and cfg.tv_sort_string() and cfg.tv_categories():
+        # Define a new sorter based on the old configuration
+        tv_sorter = {}
+        tv_sorter["order"] = order
+        tv_sorter["min_size"] = cfg.episode_rename_limit()
+        tv_sorter["multipart_label"] = ""  # Previously only available for movie sorting
+        tv_sorter["sort_string"] = cfg.tv_sort_string()
+        tv_sorter["sort_cats"] = cfg.tv_categories()
+        tv_sorter["sort_type"] = [sort_to_opts("tv")]
+        tv_sorter["is_active"] = int(cfg.enable_tv_sorting())
+
+        # Configure the new sorter
+        logging.debug("Converted old series sorter config to '%s': %s", T("Series Sorting"), tv_sorter)
+        config.ConfigSorter(T("Series Sorting"), tv_sorter)
+        order += 1
+
+    if cfg.enable_date_sorting() and cfg.date_sort_string() and cfg.date_categories():
+        date_sorter = {}
+        date_sorter["order"] = order
+        date_sorter["min_size"] = cfg.episode_rename_limit()
+        date_sorter["multipart_label"] = ""  # Previously only available for movie sorting
+        date_sorter["sort_string"] = cfg.date_sort_string()
+        date_sorter["sort_cats"] = cfg.date_categories()
+        date_sorter["sort_type"] = [sort_to_opts("date")]
+        date_sorter["is_active"] = int(cfg.enable_date_sorting())
+
+        # Configure the new sorter
+        logging.debug("Converted old date sorter config to '%s': %s", T("Date Sorting"), date_sorter)
+        config.ConfigSorter(T("Date Sorting"), date_sorter)
+        order += 1
+
+    if cfg.enable_movie_sorting() and cfg.movie_sort_string() and cfg.movie_categories():
+        movie_sorter = {}
+        movie_sorter["order"] = order
+        movie_sorter["min_size"] = cfg.movie_rename_limit()
+        movie_sorter["multipart_label"] = cfg.movie_sort_extra()
+        movie_sorter["sort_string"] = cfg.movie_sort_string()
+        movie_sorter["sort_cats"] = cfg.movie_categories()
+        movie_sorter["sort_type"] = [sort_to_opts("movie")]
+        movie_sorter["is_active"] = int(cfg.enable_movie_sorting())
+
+        # Configure the new sorter
+        logging.debug("Converted old movie sorter config to '%s': %s", T("Movie Sorting"), movie_sorter)
+        config.ConfigSorter(T("Movie Sorting"), movie_sorter)
