@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2008-2017 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2017 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -28,23 +28,23 @@ import xml.etree.ElementTree
 import datetime
 import zipfile
 import tempfile
+
 import cherrypy._cpreqbody
 from typing import Optional, Dict, Any, Union, List, Tuple
 
 import sabnzbd
 from sabnzbd import nzbstuff
-from sabnzbd.encoding import utob, correct_unknown_encoding
+from sabnzbd.encoding import utob, correct_unknown_encoding, correct_cherrypy_encoding
 from sabnzbd.filesystem import (
     get_filename,
     is_valid_script,
     get_ext,
-    setname_from_path,
     clip_path,
     remove_file,
     remove_data,
 )
 from sabnzbd.misc import name_to_cat
-from sabnzbd.constants import DEFAULT_PRIORITY, VALID_ARCHIVES
+from sabnzbd.constants import DEFAULT_PRIORITY, VALID_ARCHIVES, AddNzbFileResult
 from sabnzbd.utils import rarfile
 
 
@@ -86,7 +86,7 @@ def add_nzbfile(
     else:
         # File from file-upload object
         # CherryPy mangles unicode-filenames: https://github.com/cherrypy/cherrypy/issues/1766
-        filename = correct_unknown_encoding(nzbfile.filename)
+        filename = correct_cherrypy_encoding(nzbfile.filename)
         logging.info("Attempting to add %s", filename)
         keep_default = False
         try:
@@ -159,11 +159,9 @@ def process_nzb_archive_file(
     url: Optional[str] = None,
     password: Optional[str] = None,
     nzo_id: Optional[str] = None,
-) -> Tuple[int, List[str]]:
+) -> Tuple[AddNzbFileResult, List[str]]:
     """Analyse archive and create job(s).
     Accepts archive files with ONLY nzb/nfo/folder files in it.
-    returns (status, nzo_ids)
-        status: -1==Error, 0==OK, 1==Ignore
     """
     nzo_ids = []
     if catdir is None:
@@ -178,21 +176,22 @@ def process_nzb_archive_file(
         elif sabnzbd.newsunpack.is_sevenfile(path):
             zf = sabnzbd.newsunpack.SevenZip(path)
         else:
-            raise TypeError("File %s is not a supported archive!" % filename)
+            logging.info("File %s is not a supported archive!", filename)
+            return AddNzbFileResult.ERROR, []
     except:
         logging.info(T("Cannot read %s"), path, exc_info=True)
-        return -1, []
+        return AddNzbFileResult.RETRY, []
 
-    status = 1
+    status: AddNzbFileResult = AddNzbFileResult.NO_FILES_FOUND
     names = zf.namelist()
     nzbcount = 0
     for name in names:
         name = name.lower()
         if name.endswith(".nzb"):
-            status = 0
+            status = AddNzbFileResult.OK
             nzbcount += 1
 
-    if status == 0:
+    if status == AddNzbFileResult.OK:
         if nzbcount != 1:
             nzbname = None
         for name in names:
@@ -202,8 +201,8 @@ def process_nzb_archive_file(
                 except OSError:
                     logging.error(T("Cannot read %s"), name, exc_info=True)
                     zf.close()
-                    return -1, []
-                name = setname_from_path(name)
+                    return AddNzbFileResult.ERROR, []
+                name = get_filename(name)
                 if datap:
                     nzo = None
                     try:
@@ -218,13 +217,17 @@ def process_nzb_archive_file(
                             nzbname=nzbname,
                             nzo_info=nzo_info,
                             reuse=reuse,
+                            nzo_id=nzo_id,
                             dup_check=dup_check,
                         )
                         if not nzo.password:
                             nzo.password = password
-                    except (TypeError, ValueError):
-                        # Duplicate or empty, ignore
+                    except (sabnzbd.nzbstuff.NzbEmpty, sabnzbd.nzbstuff.NzbRejected):
+                        # Empty or fully rejected
                         pass
+                    except sabnzbd.nzbstuff.NzbRejectedToHistory as err:
+                        # Duplicate or unwanted extension that was failed to history
+                        nzo_ids.append(err.nzo_id)
                     except:
                         # Something else is wrong, show error
                         logging.error(T("Error while adding %s, removing"), name, exc_info=True)
@@ -232,13 +235,9 @@ def process_nzb_archive_file(
                         datap.close()
 
                     if nzo:
-                        if nzo_id:
-                            # Re-use existing nzo_id, when a "future" job gets it payload
-                            sabnzbd.NzbQueue.remove(nzo_id, delete_all_data=False)
-                            nzo.nzo_id = nzo_id
-                            nzo_id = None
+                        # We can only use existing nzo_id once
+                        nzo_id = None
                         nzo_ids.append(sabnzbd.NzbQueue.add(nzo))
-                        nzo.update_rating()
 
         # Close the pointer to the compressed file
         zf.close()
@@ -251,7 +250,10 @@ def process_nzb_archive_file(
             logging.info("Traceback: ", exc_info=True)
     else:
         zf.close()
-        status = 1
+
+    # If all were rejected/empty/etc, update status
+    if not nzo_ids:
+        status = AddNzbFileResult.NO_FILES_FOUND
 
     return status, nzo_ids
 
@@ -272,13 +274,10 @@ def process_single_nzb(
     url: Optional[str] = None,
     password: Optional[str] = None,
     nzo_id: Optional[str] = None,
-) -> Tuple[int, List[str]]:
+) -> Tuple[AddNzbFileResult, List[str]]:
     """Analyze file and create a job from it
     Supports NZB, NZB.BZ2, NZB.GZ and GZ.NZB-in-disguise
-    returns (status, nzo_ids)
-        status: -1==Error, 0==OK
     """
-    nzo_ids = []
     if catdir is None:
         catdir = cat
 
@@ -300,15 +299,19 @@ def process_single_nzb(
     except OSError:
         logging.warning(T("Cannot read %s"), clip_path(path))
         logging.info("Traceback: ", exc_info=True)
-        return -2, nzo_ids
+        return AddNzbFileResult.RETRY, []
 
     if filename:
         filename, cat = name_to_cat(filename, catdir)
-        # The name is used as the name of the folder, so sanitize it using folder specific santization
+        # The name is used as the name of the folder, so sanitize it using folder specific sanitization
         if not nzbname:
             # Prevent embedded password from being damaged by sanitize and trimming
             nzbname = get_filename(filename)
 
+    # Parse the data
+    result: AddNzbFileResult = AddNzbFileResult.OK
+    nzo = None
+    nzo_ids = []
     try:
         nzo = nzbstuff.NzbObject(
             filename,
@@ -321,42 +324,39 @@ def process_single_nzb(
             nzbname=nzbname,
             nzo_info=nzo_info,
             reuse=reuse,
+            nzo_id=nzo_id,
             dup_check=dup_check,
         )
         if not nzo.password:
             nzo.password = password
-    except TypeError:
-        # Duplicate, ignore
-        if nzo_id:
-            sabnzbd.NzbQueue.remove(nzo_id)
-        nzo = None
-    except ValueError:
-        # Empty
-        return 1, nzo_ids
+    except sabnzbd.nzbstuff.NzbEmpty:
+        # Malformed or might not be an NZB file
+        result = AddNzbFileResult.NO_FILES_FOUND
+    except sabnzbd.nzbstuff.NzbRejected:
+        # Rejected as duplicate or by pre-queue script
+        result = AddNzbFileResult.ERROR
+    except sabnzbd.nzbstuff.NzbRejectedToHistory as err:
+        # Duplicate or unwanted extension that was failed to history
+        nzo_ids.append(err.nzo_id)
     except:
         # Something else is wrong, show error
         logging.error(T("Error while adding %s, removing"), filename, exc_info=True)
-        return -1, nzo_ids
+        result = AddNzbFileResult.ERROR
     finally:
         nzb_fp.close()
 
     if nzo:
-        if nzo_id:
-            # Re-use existing nzo_id, when a "future" job gets it payload
-            sabnzbd.NzbQueue.remove(nzo_id, delete_all_data=False)
-            nzo.nzo_id = nzo_id
         nzo_ids.append(sabnzbd.NzbQueue.add(nzo, quiet=bool(reuse)))
-        nzo.update_rating()
 
     try:
-        if not keep:
+        if not keep and result in {AddNzbFileResult.ERROR, AddNzbFileResult.OK}:
             remove_file(path)
     except OSError:
         # Job was still added to the queue, so throw error but don't report failed add
         logging.error(T("Error removing %s"), clip_path(path))
         logging.info("Traceback: ", exc_info=True)
 
-    return 0, nzo_ids
+    return result, nzo_ids
 
 
 def nzbfile_parser(full_nzb_path: str, nzo):
@@ -422,6 +422,7 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                 # Get segments
                 raw_article_db = {}
                 file_bytes = 0
+                bad_articles = False
                 if element.find("segments"):
                     for segment in element.find("segments").iter("segment"):
                         try:
@@ -442,13 +443,14 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                                         article_id,
                                     )
                                     nzo.increase_bad_articles_counter("duplicate_articles")
+                                    bad_articles = True
                                 else:
                                     logging.info("Skipping duplicate article (%s)", article_id)
                             elif segment_size <= 0 or segment_size >= 2**23:
                                 # Perform sanity check (not negative, 0 or larger than 8MB) on article size
-                                # We use this value later to allocate memory in cache and sabyenc
                                 logging.info("Skipping article %s due to strange size (%s)", article_id, segment_size)
                                 nzo.increase_bad_articles_counter("bad_articles")
+                                bad_articles = True
                             else:
                                 raw_article_db[partnum] = (article_id, segment_size)
                                 file_bytes += segment_size
@@ -464,15 +466,13 @@ def nzbfile_parser(full_nzb_path: str, nzo):
 
                 # Check if we already have this exact NZF (see custom eq-checks)
                 if nzf in nzo.files:
-                    logging.info("File %s occured twice in NZB, skipping", nzf.filename)
+                    logging.info("File %s occurred twice in NZB, skipping", nzf.filename)
+                    remove_data(nzf.nzf_id, nzo.admin_path)
                     continue
 
                 # Add valid NZF's
                 if file_name and nzf.valid and nzf.nzf_id:
-                    logging.info("File %s added to queue", nzf.filename)
-                    nzo.files.append(nzf)
-                    nzo.files_table[nzf.nzf_id] = nzf
-                    nzo.bytes += nzf.bytes
+                    nzo.add_nzf(nzf)
                     valid_files += 1
                     avg_age_sum += file_timestamp
                 else:
