@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -718,21 +718,19 @@ class NzbQueue:
         # Pre-calculate propagation delay
         propagation_delay = float(cfg.propagation_delay() * 60)
         for nzo in self.__nzo_list:
-            # Not when queue paused and not a forced item
-            if nzo.status not in (Status.PAUSED, Status.GRABBING) or nzo.priority == FORCE_PRIORITY:
-                # Check if past propagation delay, or forced
-                if (
-                    not propagation_delay
-                    or nzo.priority == FORCE_PRIORITY
-                    or (nzo.avg_stamp + propagation_delay) < time.time()
-                ):
-                    if not nzo.server_in_try_list(server):
-                        articles = nzo.get_articles(server, servers, fetch_limit)
-                        if articles:
-                            return articles
-                    # Stop after first job that wasn't paused/propagating/etc
-                    if self.__top_only:
-                        return []
+            # Not when queue paused, individually paused, or when waiting for propagation
+            # Force items will always download
+            if (
+                not sabnzbd.Downloader.paused
+                and nzo.status not in (Status.PAUSED, Status.GRABBING)
+                and (not propagation_delay or (nzo.avg_stamp + propagation_delay) < time.time())
+            ) or nzo.priority == FORCE_PRIORITY:
+                if not nzo.server_in_try_list(server):
+                    if articles := nzo.get_articles(server, servers, fetch_limit):
+                        return articles
+                # Stop after first job that wasn't paused/propagating/etc
+                if self.__top_only:
+                    return []
         return []
 
     def register_article(self, article: Article, success: bool = True):
