@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -93,7 +93,7 @@ from sabnzbd.deobfuscate_filenames import is_probably_obfuscated
 # In the subject, we expect the filename within double quotes
 RE_SUBJECT_FILENAME_QUOTES = re.compile(r'"([^"]*)"')
 # Otherwise something that looks like a filename
-RE_SUBJECT_BASIC_FILENAME = re.compile(r"([\w\-+()'\s.,]+\.[A-Za-z0-9]{2,4})[^A-Za-z0-9]")
+RE_SUBJECT_BASIC_FILENAME = re.compile(r"([\w\-+()'\s.,]{6,}\.[A-Za-z0-9]{2,4})[^A-Za-z0-9]")
 RE_RAR = re.compile(r"(\.rar|\.r\d\d|\.s\d\d|\.t\d\d|\.u\d\d|\.v\d\d)$", re.I)
 
 
@@ -122,7 +122,7 @@ class TryList:
         """Check if all servers have been tried"""
         with TRYLIST_LOCK:
             for server in servers:
-                if not server in self.try_list:
+                if server not in self.try_list:
                     return False
         return True
 
@@ -163,6 +163,7 @@ ArticleSaver = (
     "bytes",
     "lowest_partnum",
     "decoded",
+    "file_size",
     "data_begin",
     "data_size",
     "on_disk",
@@ -187,6 +188,7 @@ class Article(TryList):
         self.fetcher_priority: int = 0
         self.tries: int = 0  # Try count
         self.decoded: bool = False
+        self.file_size: Optional[int] = None
         self.data_begin: Optional[int] = None
         self.data_size: Optional[int] = None
         self.on_disk: bool = False
@@ -419,8 +421,7 @@ class NzbFile(TryList):
         """Get next articles to be downloaded"""
         articles = []
         for article in self.articles:
-            article = article.get_article(server, servers)
-            if article:
+            if article := article.get_article(server, servers):
                 articles.append(article)
                 if len(articles) >= fetch_limit:
                     return articles
@@ -702,9 +703,9 @@ class NzbObject(TryList):
             if self.precheck:
                 self.status = Status.CHECKING
 
-        # Store one line responses for filejoin/par2/unrar/unzip here for history display
+        # Store one line responses for filejoin/par2/unrar here for history display
         self.action_line = ""
-        # Store the results from various filejoin/par2/unrar/unzip stages
+        # Store the results from various filejoin/par2/unrar stages
         self.unpack_info: Dict[str, List[str]] = {}
         # Stores one line containing the last failure
         self.fail_msg = ""
@@ -807,15 +808,13 @@ class NzbObject(TryList):
 
         if cat is None:
             for metacat in self.meta.get("category", ()):
-                metacat = cat_convert(metacat)
-                if metacat:
+                if metacat := cat_convert(metacat):
                     cat = metacat
                     break
 
         if cat is None:
             for grp in self.groups:
-                cat = cat_convert(grp)
-                if cat:
+                if cat := cat_convert(grp):
                     break
 
         # Pickup backed-up attributes when re-using
@@ -1276,8 +1275,7 @@ class NzbObject(TryList):
         existing_files = globber(wdir, "*.*")
 
         # Substitute renamed files
-        renames = sabnzbd.filesystem.load_data(RENAMES_FILE, self.admin_path, remove=True)
-        if renames:
+        if renames := sabnzbd.filesystem.load_data(RENAMES_FILE, self.admin_path, remove=True):
             for name in renames:
                 if name in existing_files or renames[name] in existing_files:
                     if name in existing_files:
@@ -1665,8 +1663,7 @@ class NzbObject(TryList):
                             else:
                                 break
 
-                        articles = nzf.get_articles(server, servers, fetch_limit)
-                        if articles:
+                        if articles := nzf.get_articles(server, servers, fetch_limit):
                             break
 
         # Remove all files for which admin could not be read
@@ -2145,22 +2142,18 @@ def scan_password(name: str) -> Tuple[str, Optional[str]]:
 
 def name_extractor(subject: str) -> str:
     """Try to extract a file name from a subject line, return `subject` if in doubt"""
-    result = subject
     # Filename nicely wrapped in quotes
     for name in re.findall(RE_SUBJECT_FILENAME_QUOTES, subject):
-        name = name.strip(' "')
-        if name:
-            result = name
+        if name := name.strip(' "'):
+            return name
 
     # Found nothing? Try a basic filename-like search
-    if result == subject:
-        for name in re.findall(RE_SUBJECT_BASIC_FILENAME, subject):
-            name = name.strip()
-            if name:
-                result = name
+    for name in re.findall(RE_SUBJECT_BASIC_FILENAME, subject):
+        if name := name.strip():
+            return name
 
     # Return the subject
-    return result
+    return subject
 
 
 def matcher(pattern, txt):
