@@ -1,6 +1,6 @@
 #!/usr/bin/python3 -OO
 # -*- coding: UTF-8 -*-
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -52,12 +52,12 @@ SKIN_TEXT = {
     "sch-rss_scan": TT("Read RSS feeds"),  #:  #: Config->Scheduler
     "sch-remove_failed": TT("Remove failed jobs"),  #: Config->Scheduler
     "sch-remove_completed": TT("Remove completed jobs"),  #: Config->Scheduler
-    "sch-pause_all_low": TT("Pause low prioirty jobs"),  #: Config->Scheduler
-    "sch-pause_all_normal": TT("Pause normal prioirty jobs"),  #: Config->Scheduler
-    "sch-pause_all_high": TT("Pause high prioirty jobs"),  #: Config->Scheduler
-    "sch-resume_all_low": TT("Resume low prioirty jobs"),  #: Config->Scheduler
-    "sch-resume_all_normal": TT("Resume normal prioirty jobs"),  #: Config->Scheduler
-    "sch-resume_all_high": TT("Resume high prioirty jobs"),  #: Config->Scheduler
+    "sch-pause_all_low": TT("Pause low priority jobs"),  #: Config->Scheduler
+    "sch-pause_all_normal": TT("Pause normal priority jobs"),  #: Config->Scheduler
+    "sch-pause_all_high": TT("Pause high priority jobs"),  #: Config->Scheduler
+    "sch-resume_all_low": TT("Resume low priority jobs"),  #: Config->Scheduler
+    "sch-resume_all_normal": TT("Resume normal priority jobs"),  #: Config->Scheduler
+    "sch-resume_all_high": TT("Resume high priority jobs"),  #: Config->Scheduler
     "sch-enable_quota": TT("Enable quota management"),  #: Config->Scheduler
     "sch-disable_quota": TT("Disable quota management"),  #: Config->Scheduler
     "sch-pause_cat": TT("Pause jobs with category"),  #: Config->Scheduler
@@ -140,8 +140,6 @@ SKIN_TEXT = {
     "cmenu-sorting": TT("Sorting"),  #: Main menu item
     "cmenu-special": TT("Special"),  #: Main menu item
     "cmenu-search": TT("Search"),  #: Main menu item
-    # Footer
-    "ft-download": TT("Download Dir"),  # Used in Footer
     # Main page
     "shutdownOK?": TT("Are you sure you want to shutdown SABnzbd?"),
     "link-pause": TT("Pause"),  #: Pause downloading
@@ -225,7 +223,6 @@ SKIN_TEXT = {
     "dashboard-IP6": TT("IPv6 address"),
     "dashboard-NameserverDNS": TT("Nameserver / DNS Lookup"),
     "dashboard-delayed": TT("Download speed limited by"),
-    "dashboard-delayed-cpu": TT("CPU"),
     "dashboard-delayed-disk": TT("Disk speed"),
     "dashboard-loadavg": TT("System load"),
     "dashboard-systemPerformance": TT("System Performance (Pystone)"),  #: Do not translate Pystone
@@ -254,13 +251,11 @@ SKIN_TEXT = {
     ),
     "confirmWithoutSavingPrompt": TT("Changes have not been saved, and will be lost."),
     "explain-sessionExpire": TT("When your IP address changes or SABnzbd is restarted the session will expire."),
-    "opt-enable_unzip": TT("Enable Unzip"),
     "opt-enable_7zip": TT("Enable 7zip"),
-    "opt-multicore-par2": TT("Multicore Par2"),
     "explain-nosslcontext": TT(
         "Secure (SSL) connections from SABnzbd to newsservers and HTTPS websites will be encrypted, however, validating a server's identity using its certificates is not possible. OpenSSL 1.0.2 or above and up-to-date local CA certificates are required."
     ),
-    "explain-getpar2mt": TT("Speed up repairs by installing multicore Par2, it is available for many platforms."),
+    "explain-getpar2turbo": TT("Speed up repairs by installing par2cmdline-turbo, it is available for many platforms."),
     "version": TT("Version"),
     "uptime": TT("Uptime"),
     "backup": TT("Backup"),  #: Indicates that server is Backup server in Status page
@@ -366,6 +361,7 @@ SKIN_TEXT = {
     "explain-complete_dir": TT(
         "Location to store finished, fully processed downloads.<br /><i>Can be overruled by user-defined categories.</i>"
     ),
+    "explain-complete_dir-sorting": TT("Use Sorting to automatically organize and rename your completed downloads."),
     "opt-complete_free": TT("Minimum Free Space for Completed Download Folder"),
     "explain-complete_free": TT("Will not work if a category folder is on a different disk."),
     "opt-fulldisk_autoresume": TT("Auto resume"),
@@ -377,9 +373,7 @@ SKIN_TEXT = {
         'Set permissions pattern for completed files/folders.<br /><i>In octal notation. For example: "755" or "777"</i>'
     ),
     "opt-dirscan_dir": TT("Watched Folder"),
-    "explain-dirscan_dir": TT(
-        "Folder to monitor for .nzb files.<br /><i>Also scans .zip .rar and .tar.gz archives for .nzb files.</i>"
-    ),
+    "explain-dirscan_dir": TT("Folder to monitor for .nzb files."),
     "opt-dirscan_speed": TT("Watched Folder Scan Speed"),
     "explain-dirscan_speed": TT("Number of seconds between scans for .nzb files."),
     "opt-script_dir": TT("Scripts Folder"),
@@ -389,6 +383,7 @@ SKIN_TEXT = {
     "opt-password_file": TT("Password file"),
     "explain-password_file": TT("File containing all passwords to be tried on encrypted RAR files."),
     "systemFolders": TT("System Folders"),
+    "hiddenFolders": TT("Hidden Folders"),
     "opt-admin_dir": TT("Administrative Folder"),
     "explain-admin_dir1": TT(
         "Location for queue admin and history database.<br /><i>Can only be changed when queue is empty.</i>"
@@ -401,6 +396,7 @@ SKIN_TEXT = {
     "explain-admin_dir2": TT("<i>Data will <b>not</b> be moved. Requires SABnzbd restart!</i>"),
     "opt-log_dir": TT("Log Folder"),
     "explain-log_dir": TT("Location of log files for SABnzbd.<br /><i>Requires SABnzbd restart!</i>"),
+    "purge_log_files": TT("Purge Logs"),
     "opt-nzb_backup_dir": TT(".nzb Backup Folder"),
     "explain-nzb_backup_dir": TT("Location where .nzb files will be stored."),
     "base-folder": TT("Default Base Folder"),
@@ -451,8 +447,6 @@ SKIN_TEXT = {
     "explain-script_can_fail": TT(
         "When the user script returns a non-zero exit code, the job will be flagged as failed."
     ),
-    "opt-new_nzb_on_failure": TT("On failure, try alternative NZB"),
-    "explain-new_nzb_on_failure": TT("Some servers provide an alternative NZB when a download fails."),
     "opt-folder_rename": TT("Enable folder rename"),
     "explain-folder_rename": TT(
         "Use temporary names during post processing. Disable when your system doesn't handle that properly."
@@ -542,11 +536,6 @@ SKIN_TEXT = {
     "explain-fail_hopeless_jobs": TT(
         "When during download it becomes clear that too much data is missing, abort the job"
     ),
-    "opt-load_balancing": TT("Server IP address selection"),
-    "no-load-balancing": TT("First IP address"),
-    "load-balancing": TT("Randomly selected IP address"),
-    "load-balancing-happy-eyeballs": TT("Quickest IP address, preferring IPv6"),
-    "explain-load_balancing": TT("Useful if a newsserver has more than one IPv4/IPv6 address"),
     # Config->Server
     "addServer": TT("Add Server"),  #: Caption
     "srv-displayname": TT("Server description"),  #: User defined name for server
@@ -615,6 +604,7 @@ SKIN_TEXT = {
     "addMultipleFeeds": TT("Seperate multiple URLs by a comma"),  #: Config->RSS, placeholder (cannot be too long)
     "button-preFeed": TT("Read Feed"),  #: Config->RSS button
     "button-forceFeed": TT("Force Download"),  #: Config->RSS button
+    "button-evalFeed": TT("Apply filters"),
     "rss-edit": TT("Edit"),  #: Config->RSS edit button
     "rss-nextscan": TT("Next scan at"),  #: Config->RSS when will be the next RSS scan
     "rss-order": TT("Order"),  #: Config->RSS table column header
@@ -709,29 +699,19 @@ SKIN_TEXT = {
     "catFolderPath": TT("Folder/Path"),
     "catTags": TT("Indexer Categories / Groups"),
     # Config->Sorting
-    "selectOneCat": TT("Select at least 1 category."),
-    "seriesSorting": TT("Series Sorting"),
-    "opt-tvsort": TT("Enable TV Sorting"),
     "sort-legenda": TT("Pattern Key"),
     "button-clear": TT("Clear"),
-    "button-evalFeed": TT("Apply filters"),
-    "presetSort": TT("Presets"),
     "movieSort": TT("Movie Sorting"),
-    "opt-movieSort": TT("Enable Movie Sorting"),
+    "seriesSort": TT("Series Sorting"),
+    "presetSort": TT("Presets"),
     "affectedCat": TT("Affected Categories"),
     "sort-meaning": TT("Meaning"),
     "sort-pattern": TT("Pattern"),
     "sort-result": TT("Result"),
-    "button-Season1x05": TT("1x05 Season Folder"),
-    "button-SeasonS01E05": TT("S01E05 Season Folder"),
-    "button-Ep1x05": TT("1x05 Episode Folder"),
-    "button-EpS01E05": TT("S01E05 Episode Folder"),
-    "button-FileLikeFolder": TT("Job Name as Filename"),
     "sort-title": TT("Title"),
     "movie-sp-name": TT("Movie Name"),
     "movie-dot-name": TT("Movie.Name"),
     "movie-us-name": TT("Movie_Name"),
-    "show-name": TT("Show Name"),
     "show-sp-name": TT("Show Name"),
     "show-dot-name": TT("Show.Name"),
     "show-us-name": TT("Show_Name"),
@@ -741,7 +721,6 @@ SKIN_TEXT = {
     "ep-sp-name": TT("Episode Name"),
     "ep-dot-name": TT("Episode.Name"),
     "ep-us-name": TT("Episode_Name"),
-    "fileExt": TT("File Extension"),
     "extension": TT("Extension"),
     "partNumber": TT("Part Number"),
     "decade": TT("Decade"),
@@ -752,14 +731,13 @@ SKIN_TEXT = {
     "text": TT("text"),
     "sort-File": TT("file"),
     "sortString": TT("Sort String"),
-    "multiPartLabel": TT("Multi-part label"),
+    "multiPartLabel": TT("Multi-part Label"),
+    "button-showFolder": TT("Show folder"),
+    "button-seasonFolder": TT("Season folder"),
     "button-inFolders": TT("In folders"),
     "button-noFolders": TT("No folders"),
-    "dateSorting": TT("Date Sorting"),
-    "opt-dateSort": TT("Enable Date Sorting"),
-    "button-ShowNameF": TT("Show Name folder"),
-    "button-YMF": TT("Year-Month Folders"),
-    "button-DailyF": TT("Daily Folders"),
+    "button-FileLikeFolder": TT("Job Name as Filename"),
+    "button-Series": TT("Series"),
     "case-adjusted": TT("case-adjusted"),  #: Note for title expression in Sorting that does case adjustment
     "sortResult": TT("Processed Result"),
     "sort-guessitMeaning": TT("Any property"),
@@ -767,6 +745,31 @@ SKIN_TEXT = {
     "guessit-sp-property": TT("GuessIt Property"),
     "guessit-dot-property": TT("GuessIt.Property"),
     "guessit-us-property": TT("GuessIt_Property"),
+    "sort-minimum-size": TT("Minimum Filesize"),
+    "guessit-type": TT("Affected Job Types"),
+    "guessit-type-all": TT("All"),
+    "guessit-type-tv": TT("Series"),
+    "guessit-type-date": TT("Series with air dates"),
+    "guessit-type-movie": TT("Movies"),
+    "guessit-type-other": TT("Other / Unknown"),
+    "explain-sorting": TT(
+        "<p>Use Sorters to automatically organize your completed downloads. For example, put all episodes from a series "
+        "in a season-specific folder. Or, put movies in a folder named after the movie.</p>"
+        "<p>Sorters are tried in order of appearance and can be reordered by dragging and dropping.<br/>"
+        "The first active sorter that matches both the affected category and job type is applied.</p>"
+        "<p>More options are available when Advanced Settings is checked.<br/>"
+        "Detailed information can be found on the Wiki.</p>"
+    ),
+    "add-sorter": TT("Add Sorter"),
+    "remove-sorter": TT("Remove Sorter"),
+    "sort-test-data": TT("Test Data"),
+    "sort-quick-add": TT("Quick start"),
+    "sort-quick-add-series": TT(
+        'Move and rename all episodes in the "tv" category to a show-specific folder'
+    ),  #: Do not translate "tv"!
+    "sort-quick-add-movies": TT(
+        'Move and rename all movies in the "movies" category to a movie-specific folder'
+    ),  #: Do not translate "movies"!
     # Config->Special
     "explain-special": TT(
         "Rarely used options. For their meaning and explanation, click on the Help button to go to the Wiki page.<br>"
@@ -856,6 +859,7 @@ SKIN_TEXT = {
     "Glitter-confirmDeleteQueue": TT("Confirm Queue Deletions"),
     "Glitter-confirmDeleteHistory": TT("Confirm History Deletions"),
     "Glitter-keyboardShortcuts": TT("Keyboard shortcuts"),
+    "Glitter-keyboardShortcuts-arrows": TT("Shift+Arrow key: Browse Queue and History pages"),
     "Glitter-pausePrompt": TT("How long or untill when do you want to pause? (in English!)"),
     "Glitter-pausePromptFail": TT("Sorry, we could not interpret that. Try again."),
     "Glitter-pauseFor": TT("Pause for..."),
