@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -414,7 +414,7 @@ class Sorter:
     def _rename_season_pack(self, files: List[str], base_path: str, all_job_files: List[str] = []) -> bool:
         success = False
         for f in files:
-            f_name, f_ext = os.path.splitext(f)
+            f_name, f_ext = os.path.splitext(os.path.basename(f))
             if f_episode := guessit.api.guessit(f_name).get("episode"):
                 # Insert formatted episode number(s) into self.info
                 self.format_series_numbers(f_episode, "episode_num")
@@ -432,7 +432,7 @@ class Sorter:
                         ("%ext", f_ext.lstrip(".")),
                     ],
                 )
-                f_new = f_name_new + f_ext
+                f_new = to_lowercase(f_name_new + f_ext)
 
                 try:
                     logging.debug("Renaming season pack file %s to %s", f, f_new)
@@ -477,11 +477,13 @@ class Sorter:
             f_name, f_ext = os.path.splitext(os.path.split(f)[1])
             new_filepath = os.path.join(
                 base_path,
-                path_subst(
-                    self.filename_set + self.multipart_label,
-                    [("%1", str(index)), ("%fn", f_name), ("%ext", f_ext.lstrip("."))],
-                )
-                + f_ext,
+                to_lowercase(
+                    path_subst(
+                        self.filename_set + self.multipart_label,
+                        [("%1", str(index)), ("%fn", f_name), ("%ext", f_ext.lstrip("."))],
+                    )
+                    + f_ext,
+                ),
             )
             try:
                 logging.debug("Renaming %s to %s", filepath, new_filepath)
@@ -509,7 +511,7 @@ class Sorter:
 
     def rename(self, files: List[str], base_path: str) -> Tuple[str, bool]:
         if not self.rename_files:
-            return base_path, True
+            return move_to_parent_directory(base_path)
 
         # Log the minimum filesize for renaming
         if self.rename_limit > 0:
@@ -557,7 +559,8 @@ class Sorter:
         f_name, f_ext = os.path.splitext(largest_file.get("name"))
         filepath = self._to_filepath(largest_file.get("name"), base_path)
         new_filepath = os.path.join(
-            base_path, path_subst(self.filename_set, [("%fn", f_name), ("%ext", f_ext.lstrip("."))]) + f_ext
+            base_path,
+            to_lowercase(path_subst(self.filename_set, [("%fn", f_name), ("%ext", f_ext.lstrip("."))]) + f_ext),
         )
         if not os.path.exists(new_filepath):
             renamed_files = []
