@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2022 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,7 +24,7 @@ import sys
 
 from sabnzbd.constants import DEF_TIMEOUT
 from sabnzbd.newswrapper import NewsWrapper, NNTPPermanentError
-from sabnzbd.downloader import Server, clues_login, clues_too_many, nntp_to_msg
+from sabnzbd.downloader import Server, clues_login, clues_too_many
 from sabnzbd.config import get_servers
 from sabnzbd.misc import int_conv, match_str
 
@@ -89,8 +89,7 @@ def test_nntp_server_dict(kwargs):
         nw = NewsWrapper(server=s, thrdnum=-1, block=True)
         nw.init_connect()
         while not nw.connected:
-            nw.clear_data()
-            nw.recv_chunk(block=True)
+            nw.recv_chunk()
             nw.finish_connect(nw.status_code)
 
     except socket.timeout:
@@ -123,8 +122,8 @@ def test_nntp_server_dict(kwargs):
     if not username or not password:
         nw.nntp.sock.sendall(b"ARTICLE <test@home>\r\n")
         try:
-            nw.clear_data()
-            nw.recv_chunk(block=True)
+            nw.reset_data_buffer()
+            nw.recv_chunk()
         except:
             # Some internal error, not always safe to close connection
             return False, str(sys.exc_info()[1])
@@ -137,14 +136,14 @@ def test_nntp_server_dict(kwargs):
         elif nw.status_code < 300 or nw.status_code in (411, 423, 430):
             # If no username/password set and we requested fake-article, it will return 430 Not Found
             return_status = (True, T("Connection Successful!"))
-        elif nw.status_code == 502 or clues_login(nntp_to_msg(nw.data)):
+        elif nw.status_code == 502 or clues_login(nw.nntp_msg):
             return_status = (False, T("Authentication failed, check username/password."))
-        elif clues_too_many(nntp_to_msg(nw.data)):
+        elif clues_too_many(nw.nntp_msg):
             return_status = (False, T("Too many connections, please pause downloading or try again later"))
 
     # Fallback in case no data was received or unknown status
     if not return_status:
-        return_status = (False, T("Could not determine connection result (%s)") % nntp_to_msg(nw.data))
+        return_status = (False, T("Could not determine connection result (%s)") % nw.nntp_msg)
 
     # Close the connection and return result
     nw.hard_reset(send_quit=True)
